from bergen.query import DelayedGQL


GET_REPRESENTATION = DelayedGQL("""
query Representation($id: Int!){
  representation(id: $id){
    id
    name
    image
    store
    unique
  
  }
}
""")

CREATE_REPRESENTATION = DelayedGQL("""
mutation Representation($sample: ID!, $name: String!){
  createRepresentation(sample: $sample, name: $name){
    name
    id
    image
    store
    unique
  
  }
}
""")

UPDATE_REPRESENTATION = DelayedGQL("""
mutation Representation($id: ID!){
  updateRepresentation(rep: $id){
    name
    id
    image
    store
    unique
  }
}
""")


FILTER_REPRESENTATION = DelayedGQL("""
query Representation($name: String) {
  representations(name: $name) {
    name
    store
  }
}
""")


from grunnlag.gql import CREATE_REPRESENTATION, GET_REPRESENTATION, UPDATE_REPRESENTATION, FILTER_REPRESENTATION
from grunnlag.managers import RepresentationManager
from typing import List, Optional
from bergen.schema import ArnheimModel, User
from grunnlag.extenders import Array, RepresentationPrettifier

class Representation(RepresentationPrettifier, Array, ArnheimModel):
    id: Optional[int]
    name: Optional[str]
    package: Optional[str]
    store: Optional[str]
    shape: Optional[List[int]]
    image: Optional[str]
    creator: Optional[User]
    unique: Optional[str]

    objects = RepresentationManager

    class Meta:
        identifier = "representation"
        get = GET_REPRESENTATION
        create = CREATE_REPRESENTATION
        update = UPDATE_REPRESENTATION
        filter = FILTER_REPRESENTATION







# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['grunnlag']

package_data = \
{'': ['*']}

install_requires = \
['bergen>=0.1.3,<0.2.0',
 'dask[complete]>=2020.12.0,<2021.0.0',
 's3fs>=0.5.2,<0.6.0',
 'xarray[complete]>=0.16.2,<0.17.0',
 'zarr>=2.6.1,<3.0.0']

setup_kwargs = {
    'name': 'grunnlag',
    'version': '0.1.1',
    'description': 'Basic Schema for interacting with Arnheim through Bergen',
    'long_description': None,
    'author': 'jhnnsrs',
    'author_email': 'jhnnsrs@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
